==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/ChartSortDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ChartSortDescriptionDescription } from "./ChartSortDescriptionDescription";
/**
 * @hidden
 */
var ChartSortDescriptionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ChartSortDescriptionDescriptionMetadata, _super);
    function ChartSortDescriptionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChartSortDescriptionDescriptionMetadata.b = function (a) {
        if (ChartSortDescriptionDescriptionMetadata.a == null) {
            ChartSortDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ChartSortDescriptionDescriptionMetadata.c(ChartSortDescriptionDescriptionMetadata.a);
        }
        if (a.g(ChartSortDescriptionDescriptionMetadata.a)) {
            return;
        }
        a.s(ChartSortDescriptionDescriptionMetadata.a);
    };
    ChartSortDescriptionDescriptionMetadata.c = function (a) {
        a.item("Field", "String");
        a.item("SortDirection", "ExportedType:string:ListSortDirection");
        a.item("SortDirection@names", "Ascending;Descending");
    };
    ChartSortDescriptionDescriptionMetadata.d = function (a) {
        ChartSortDescriptionDescriptionMetadata.b(a);
        a.u("ChartSortDescription", function () { return new ChartSortDescriptionDescription(); });
        a.t("ChartSortDescription", ChartSortDescriptionDescriptionMetadata.a);
    };
    ChartSortDescriptionDescriptionMetadata.$t = markType(ChartSortDescriptionDescriptionMetadata, 'ChartSortDescriptionDescriptionMetadata');
    ChartSortDescriptionDescriptionMetadata.a = null;
    return ChartSortDescriptionDescriptionMetadata;
}(Base));
export { ChartSortDescriptionDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/ChartSortDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ChartSortDescriptionDescription } from "./ChartSortDescriptionDescription";
/**
 * @hidden
 */
var ChartSortDescriptionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ChartSortDescriptionDescriptionMetadata, _super);
    function ChartSortDescriptionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChartSortDescriptionDescriptionMetadata.b = function (a) {
        if (ChartSortDescriptionDescriptionMetadata.a == null) {
            ChartSortDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ChartSortDescriptionDescriptionMetadata.c(ChartSortDescriptionDescriptionMetadata.a);
        }
        if (a.j(ChartSortDescriptionDescriptionMetadata.a)) {
            return;
        }
        a.y(ChartSortDescriptionDescriptionMetadata.a);
    };
    ChartSortDescriptionDescriptionMetadata.c = function (a) {
        a.item("Field", "String");
        a.item("SortDirection", "ExportedType:string:ListSortDirection");
        a.item("SortDirection@names", "Ascending;Descending");
    };
    ChartSortDescriptionDescriptionMetadata.d = function (a) {
        ChartSortDescriptionDescriptionMetadata.b(a);
        a.aa("ChartSortDescription", function () { return new ChartSortDescriptionDescription(); });
        a.z("ChartSortDescription", ChartSortDescriptionDescriptionMetadata.a);
    };
    ChartSortDescriptionDescriptionMetadata.$t = markType(ChartSortDescriptionDescriptionMetadata, 'ChartSortDescriptionDescriptionMetadata');
    ChartSortDescriptionDescriptionMetadata.a = null;
    return ChartSortDescriptionDescriptionMetadata;
}(Base));
export { ChartSortDescriptionDescriptionMetadata };
